@@ -25,10 +25,10 @@ logger.setLevel(logging.INFO)
 @click.command()
 @click.version_option(_version.__version__)
 @click.option(
-    '--meta-csv',
-    'meta_csv_path',
+    '--meta-tsv',
+    'meta_tsv_path',
     required=True,
-    help='path to a CSV with QC and population metadata for the samples',
+    help='path to a TSV with QC and population metadata for the samples',
 )
 @click.option(
     '--hard-filtered-samples-ht',
@@ -77,9 +77,6 @@ logger.setLevel(logging.INFO)
     'filter_cutoffs_path',
     help=f'YAML file with filtering cutoffs',
 )
-@click.option(
-    '--age-csv', 'age_csv_path', help='CSV file with 2 columns: `sample` and `age`'
-)
 @click.option(
     '--out-meta-ht',
     'out_meta_ht_path',
@@ -110,7 +107,7 @@ logger.setLevel(logging.INFO)
     help='Hail billing account ID.',
 )
 def main(  # pylint: disable=too-many-arguments,too-many-locals,missing-function-docstring
-    meta_csv_path: str,
+    meta_tsv_path: str,
     hard_filtered_samples_ht_path: str,
     hail_sample_qc_ht_path: str,
     sex_ht_path: str,
@@ -119,7 +116,6 @@ def main(  # pylint: disable=too-many-arguments,too-many-locals,missing-function
     relatedness_ht_path: str,
     pop_ht_path: str,
     filter_cutoffs_path: str,
-    age_csv_path: str,
     out_meta_ht_path: str,
     out_meta_tsv_path: str,
     tmp_bucket: str,
@@ -130,7 +126,7 @@ def main(  # pylint: disable=too-many-arguments,too-many-locals,missing-function
 
     cutoffs_d = utils.get_filter_cutoffs(filter_cutoffs_path)
 
-    input_metadata_ht = utils.parse_input_metadata(meta_csv_path, local_tmp_dir)
+    input_metadata_ht = utils.parse_input_metadata(meta_tsv_path, local_tmp_dir)
     hard_filtered_samples_ht = hl.read_table(hard_filtered_samples_ht_path)
     sex_ht = hl.read_table(sex_ht_path)
     custom_qc_ht = hl.read_table(custom_qc_ht_path)
@@ -139,16 +135,6 @@ def main(  # pylint: disable=too-many-arguments,too-many-locals,missing-function
     relatedness_ht = hl.read_table(relatedness_ht_path)
     pop_ht = hl.read_table(pop_ht_path)
 
-    if age_csv_path:
-        age_ht = (
-            hl.import_table(age_csv_path, delimiter=',', types={'age': 'float'})
-            .rename({'TOBIID': 's'})
-            .key_by('s')
-        )
-        input_metadata_ht = input_metadata_ht.annotate(
-            age=age_ht[input_metadata_ht.external_id].age,
-        )
-
     # Re-calculating the maximum set of unrelated samples now that
     # we have metrics adjusted for population, so newly QC-failed samples
     # are excluded
